Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(243)

Unified Diff: content/common/view_messages.h

Issue 518693002: Fix a crash when saving a <canvas> or <img> image which is large. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/common/view_messages.h
diff --git a/content/common/view_messages.h b/content/common/view_messages.h
index 14efdaf160ec3a4def42d671b2624b47b37b9316..083570f738607e5677f141203ac5213488d8a51f 100644
--- a/content/common/view_messages.h
+++ b/content/common/view_messages.h
@@ -1252,12 +1252,18 @@ IPC_MESSAGE_ROUTED2(ViewHostMsg_AppCacheAccessed,
bool /* blocked by policy */)
// Initiates a download based on user actions like 'ALT+click'.
-IPC_MESSAGE_CONTROL5(ViewHostMsg_DownloadUrl,
+IPC_MESSAGE_CONTROL4(ViewHostMsg_DownloadUrl,
int /* render_view_id */,
GURL /* url */,
content::Referrer /* referrer */,
- base::string16 /* suggested_name */,
- bool /* use prompt for save location */)
+ base::string16 /* suggested_name */)
+
+// Save image for <canvas>.
Ken Russell (switch to Gerrit) 2014/08/29 23:29:26 Please document that |encoded_image_data| is the c
+IPC_MESSAGE_CONTROL4(ViewHostMsg_SaveImageAs,
+ int /* render_view_id */,
+ std::string /* encoded_image_data */,
Ken Russell (switch to Gerrit) 2014/08/29 23:29:26 Some guard against DOS'ing the browser process is
palmer 2014/08/30 00:37:29 Yeah, It's probably better to send the browser pro
Ken Russell (switch to Gerrit) 2014/08/30 00:52:09 Chris, in this case I think it's better to send th
+ content::Referrer /* referrer */,
+ base::string16 /* suggested_name */)
palmer 2014/08/30 00:37:29 Make sure the browser side (a) takes the basename
// Used to go to the session history entry at the given offset (ie, -1 will
// return the "back" item).

Powered by Google App Engine
This is Rietveld 408576698